@@ -5,9 +5,8 @@ from flask_restful import Resource
 from flask_restful import reqparse
 from flask_restful import marshal_with
 from rest_server.resource.models.helper import resource_fields
-from test_framework.state import State
-from test_framework.state import NodeState
 from test_framework.dut.dut import Dut
+from utils import log
 
 
 PARSER = reqparse.RequestParser()
@@ -21,6 +20,7 @@ class DutResource(Resource):
 
     @marshal_with(resource_fields, envelope='resource')
     def post(self):
+        log.INFO("REST refresh DUT")
         args = PARSER.parse_args()
         dut = Dut()
         dut.refresh()
