@@ -2,6 +2,7 @@
 import os
 from utils import log
 from test_framework.database.database import SqlConnection
+from test_framework.state import SlotState
 from utils.system import get_ip_address
 
 
@@ -70,6 +71,27 @@ class DutDatabase(SqlConnection):
         result = self.execute_sql_command(cmd)
         return result
 
+    def agent_heart_beat(self, state):
+        update_time = self.get_datetime()
+        status = "`status`='{}', update_time='{}'".format(state, update_time)
+        update_command = "UPDATE {} SET {} WHERE ip='{}' AND port='{}'".\
+            format(self.agent_table, status, self.ip_address, self.port)
+        self.cursor.execute(update_command)
+        self.conn.commit()
+
+    def delete_removed_slot(self, slot_id):
+        if slot_id is not None:
+            update_command = "DELETE FROM {} WHERE `id`='{}'".format(self.slot_table, slot_id)
+            self.cursor.execute(update_command)
+            self.conn.commit()
+
+    def set_slot_to_lost(self, slot_id):
+        if slot_id is not None:
+            log.INFO("Find slot is lost: {}".format(slot_id))
+            cmd = "UPDATE  {} SET `status`='{}' WHERE `id`='{}'".format(self.slot_table, SlotState.Lost, slot_id)
+            self.cursor.execute(cmd)
+            self.conn.commit()
+
 
 def update_agent(func):
     def func_wrapper(*args, **kwargs):
@@ -86,15 +108,52 @@ def update_agent(func):
 def update_slot(func):
     def func_wrapper(*args, **kwargs):
         slot_id, slot = func(*args, **kwargs)
-        try:
-            sql_connection = DutDatabase()
-            sql_connection.update_slot(slot_id, slot)
-        except Exception as all_exception:
-            log.ERR(all_exception)
-        return slot
+        if slot is not None:
+            try:
+                sql_connection = DutDatabase()
+                sql_connection.update_slot(slot_id, slot)
+            except Exception as all_exception:
+                log.ERR(all_exception)
+        return slot_id, slot
     return func_wrapper
 
-#
+
+def agent_heart_beat(func):
+    def func_wrapper(*args, **kwargs):
+        status = func(*args, **kwargs)
+        try:
+            sql_connection = DutDatabase()
+            sql_connection.agent_heart_beat(status)
+        except Exception as all_exception:
+            log.ERR(all_exception)
+        return status
+    return func_wrapper
+
+
+def delete_removed_slot(func):
+    def func_wrapper(*args, **kwargs):
+        slot_id = func(*args, **kwargs)
+        try:
+            sql_connection = DutDatabase()
+            sql_connection.delete_removed_slot(slot_id)
+        except Exception as all_exception:
+            log.ERR(all_exception)
+        return slot_id
+    return func_wrapper
+
+
+def check_lost_slot(func):
+    def func_wrapper(*args, **kwargs):
+        slot_id = func(*args, **kwargs)
+        try:
+            sql_connection = DutDatabase()
+            sql_connection.set_slot_to_lost(slot_id)
+        except Exception as all_exception:
+            log.ERR(all_exception)
+        return slot_id
+    return func_wrapper
+
+
 # if __name__ == '__main__':
 #     dutdb = DutDatabase()
 #     agent = {
@@ -121,5 +180,3 @@ def update_slot(func):
 #         "agent": "172.29.129.143:5000"
 #
 #     }
-#
-#     dutdb.create_new_agent(agent)
