@@ -1,7 +1,7 @@
 
 import os
 import platform
-from utils.system import get_ip_address
+from utils.system import get_ip_address, get_platform
 from test_framework.database.dut_database import update_agent
 
 
@@ -16,7 +16,7 @@ class Agent(object):
         agent_info["ip"] = self.ip_address
         agent_info["port"] = self.port
         agent_info["os"] = "windows" if platform.system() == 'Windows' else "linux"
-        agent_info["platform"] = os.environ.get('platform', "")
+        agent_info["platform"] = get_platform()
         return agent_info
 
     def get_agent_name(self):
